@@ -8,7 +8,7 @@ Attean::Plan - Representation of SPARQL query plan operators
 
 =head1 VERSION
 
-This document describes Attean::Plan version 0.031
+This document describes Attean::Plan version 0.032
 
 =head1 SYNOPSIS
 
@@ -32,7 +32,7 @@ Evaluates a quad pattern against the model.
 
 =cut
 
-package Attean::Plan::Quad 0.031 {
+package Attean::Plan::Quad 0.032 {
 	use Moo;
 	use Scalar::Util qw(blessed reftype);
 	use Types::Standard qw(ConsumerOf ArrayRef);
@@ -137,7 +137,7 @@ Evaluates a join (natural-, anti-, or left-) using a nested loop.
 
 =cut
 
-package Attean::Plan::NestedLoopJoin 0.031 {
+package Attean::Plan::NestedLoopJoin 0.032 {
 	use Moo;
 	use List::MoreUtils qw(all);
 	use namespace::clean;
@@ -226,7 +226,7 @@ Evaluates a join (natural-, anti-, or left-) using a hash join.
 
 =cut
 
-package Attean::Plan::HashJoin 0.031 {
+package Attean::Plan::HashJoin 0.032 {
 	use Moo;
 	use List::MoreUtils qw(all);
 	use namespace::clean;
@@ -367,7 +367,7 @@ package Attean::Plan::HashJoin 0.031 {
 
 =cut
 
-package Attean::Plan::Construct 0.031 {
+package Attean::Plan::Construct 0.032 {
 	use Moo;
 	use List::MoreUtils qw(all);
 	use Types::Standard qw(Str ArrayRef ConsumerOf InstanceOf);
@@ -458,7 +458,7 @@ package Attean::Plan::Construct 0.031 {
 
 =cut
 
-package Attean::Plan::Describe 0.031 {
+package Attean::Plan::Describe 0.032 {
 	use Moo;
 	use Attean::RDF;
 	use List::MoreUtils qw(all);
@@ -544,7 +544,7 @@ named variable binding.
 
 =cut
 
-package Attean::Plan::EBVFilter 0.031 {
+package Attean::Plan::EBVFilter 0.032 {
 	use Moo;
 	use Scalar::Util qw(blessed);
 	use Types::Standard qw(Str ConsumerOf);
@@ -603,7 +603,7 @@ ordering.
 
 =cut
 
-package Attean::Plan::Merge 0.031 {
+package Attean::Plan::Merge 0.032 {
 	use Moo;
 	use Scalar::Util qw(blessed);
 	use Types::Standard qw(Str ArrayRef ConsumerOf);
@@ -632,7 +632,7 @@ Evaluates a set of sub-plans, returning the union of results.
 
 =cut
 
-package Attean::Plan::Union 0.031 {
+package Attean::Plan::Union 0.032 {
 	use Moo;
 	use Scalar::Util qw(blessed);
 	use namespace::clean;
@@ -703,7 +703,7 @@ expressions, binding the produced values to new variables.
 
 =cut
 
-package Attean::Plan::Extend 0.031 {
+package Attean::Plan::Extend 0.032 {
 	use Moo;
 	use Encode;
 	use UUID::Tiny ':std';
@@ -722,6 +722,7 @@ package Attean::Plan::Extend 0.031 {
 	with 'Attean::API::BindingSubstitutionPlan', 'Attean::API::UnaryQueryTree';
 	has 'expressions' => (is => 'ro', isa => HashRef[ConsumerOf['Attean::API::Expression']], required => 1);
 	
+	
 	sub plan_as_string {
 		my $self	= shift;
 		my @strings	= map { sprintf('?%s ← %s', $_, $self->expressions->{$_}->as_string) } keys %{ $self->expressions };
@@ -1265,6 +1266,14 @@ package Attean::Plan::Extend 0.031 {
 				my $pos	= lc($func);
 				my $term	= $operands[0]->$pos();
 				return $term;
+			} elsif ($func eq 'INVOKE') {
+				my @operands	= map { $self->evaluate_expression($model, $_, $r) } @{ $expr->children };
+				my $furi		= shift(@operands)->value;
+				my $func		= Attean->get_global_function($furi);
+				unless (ref($func)) {
+					die "No extension registered for <$furi>";
+				}
+				return $func->(@operands);
 			} else {
 				warn "Expression evaluation unimplemented: " . $expr->as_string;
 				$self->log->warn("Expression evaluation unimplemented: " . $expr->as_string);
@@ -1356,7 +1365,7 @@ hash of already-seen results.
 
 =cut
 
-package Attean::Plan::HashDistinct 0.031 {
+package Attean::Plan::HashDistinct 0.032 {
 	use Moo;
 	use namespace::clean;
 	
@@ -1384,7 +1393,7 @@ filtering out sequential duplicates.
 
 =cut
 
-package Attean::Plan::Unique 0.031 {
+package Attean::Plan::Unique 0.032 {
 	use Moo;
 	use namespace::clean;
 	
@@ -1419,7 +1428,7 @@ number of results ("offset") and limiting the total number of returned results
 
 =cut
 
-package Attean::Plan::Slice 0.031 {
+package Attean::Plan::Slice 0.032 {
 	use Moo;
 	use Types::Standard qw(Int);
 	use namespace::clean;
@@ -1460,7 +1469,7 @@ of variable bindings in each result.
 
 =cut
 
-package Attean::Plan::Project 0.031 {
+package Attean::Plan::Project 0.032 {
 	use Moo;
 	with 'Attean::API::BindingSubstitutionPlan', 'Attean::API::UnaryQueryTree';
 	use Types::Standard qw(ArrayRef ConsumerOf);
@@ -1537,7 +1546,7 @@ sorting is applied.
 
 =cut
 
-package Attean::Plan::OrderBy 0.031 {
+package Attean::Plan::OrderBy 0.032 {
 	use Moo;
 	use Types::Standard qw(HashRef ArrayRef InstanceOf Bool Str);
 	use Scalar::Util qw(blessed);
@@ -1620,7 +1629,7 @@ Evaluates a SPARQL query against a remote endpoint.
 
 =cut
 
-package Attean::Plan::Service 0.031 {
+package Attean::Plan::Service 0.032 {
 	use Moo;
 	use Types::Standard qw(ConsumerOf Bool Str);
 	use namespace::clean;
@@ -1652,7 +1661,7 @@ Returns a constant set of results.
 
 =cut
 
-package Attean::Plan::Table 0.031 {
+package Attean::Plan::Table 0.032 {
 	use Moo;
 	use Types::Standard qw(ArrayRef ConsumerOf);
 	use namespace::clean;
@@ -1717,7 +1726,7 @@ L<Attean::ListIterator>, the size of that iterator will be used.
 
 =cut
 
-package Attean::Plan::Iterator 0.031 {
+package Attean::Plan::Iterator 0.032 {
 	use Moo;
 	use Types::Standard qw(ArrayRef ConsumerOf Int);
 	use namespace::clean;
@@ -1781,7 +1790,7 @@ package Attean::Plan::Iterator 0.031 {
 
 =cut
 
-package Attean::Plan::ALPPath 0.031 {
+package Attean::Plan::ALPPath 0.032 {
 	use Moo;
 	use Attean::TreeRewriter;
 	use Types::Standard qw(ArrayRef ConsumerOf);
@@ -1933,7 +1942,7 @@ package Attean::Plan::ALPPath 0.031 {
 	}
 }
 
-package Attean::Plan::ZeroOrOnePath 0.031 {
+package Attean::Plan::ZeroOrOnePath 0.032 {
 	use Moo;
 	use Attean::TreeRewriter;
 	use Types::Standard qw(ArrayRef ConsumerOf);
@@ -2032,7 +2041,7 @@ results were produced by evaluating the sub-plan.
 
 =cut
 
-package Attean::Plan::Exists 0.031 {
+package Attean::Plan::Exists 0.032 {
 	use Moo;
 	use Types::Standard qw(ArrayRef ConsumerOf);
 	use namespace::clean;
@@ -2062,7 +2071,7 @@ package Attean::Plan::Exists 0.031 {
 
 =cut
 
-package Attean::Plan::Aggregate 0.031 {
+package Attean::Plan::Aggregate 0.032 {
 	use Moo;
 	use Encode;
 	use UUID::Tiny ':std';
@@ -2184,6 +2193,22 @@ package Attean::Plan::Aggregate 0.031 {
 			}
 			my $string	= join($sep, @values);
 			return Attean::Literal->new(value => $string);
+		} elsif ($op eq 'CUSTOM') {
+			my $iri	= $expr->custom_iri;
+			my $data	= Attean->get_global_aggregate($iri);
+			unless ($data) {
+				die "No extension aggregate registered for <$iri>";
+			}
+			my $start	= $data->{'start'};
+			my $process	= $data->{'process'};
+			my $finalize	= $data->{'finalize'};
+
+			my $thunk	= $start->();
+			foreach my $r (@$rows) {
+				my $t	= Attean::Plan::Extend->evaluate_expression($model, $e, $r);
+				$process->($thunk, $t);
+			}
+			return $finalize->($thunk);
 		}
 		die "$op not implemented";
 	}
@@ -2291,7 +2316,7 @@ package Attean::Plan::Aggregate 0.031 {
 	}
 }
 
-package Attean::Plan::Sequence 0.031 {
+package Attean::Plan::Sequence 0.032 {
 	use Moo;
 	use Scalar::Util qw(blessed);
 	use Types::Standard qw(ConsumerOf ArrayRef);
@@ -2316,7 +2341,7 @@ package Attean::Plan::Sequence 0.031 {
 	}
 }
 
-package Attean::Plan::Clear 0.031 {
+package Attean::Plan::Clear 0.032 {
 	use Moo;
 	use Scalar::Util qw(blessed);
 	use Types::Standard qw(ConsumerOf ArrayRef);
@@ -2353,7 +2378,7 @@ package Attean::Plan::Clear 0.031 {
 	}
 }
 
-package Attean::Plan::Drop 0.031 {
+package Attean::Plan::Drop 0.032 {
 	use Moo;
 	use Scalar::Util qw(blessed);
 	use Types::Standard qw(ConsumerOf ArrayRef);
@@ -2388,7 +2413,7 @@ package Attean::Plan::Drop 0.031 {
 	}
 }
 
-package Attean::Plan::TripleTemplateToModelQuadMethod 0.031 {
+package Attean::Plan::TripleTemplateToModelQuadMethod 0.032 {
 	use Moo;
 	use Scalar::Util qw(blessed);
 	use Types::Standard qw(ConsumerOf Str ArrayRef HashRef);
@@ -2464,7 +2489,7 @@ package Attean::Plan::TripleTemplateToModelQuadMethod 0.031 {
 	}
 }
 
-package Attean::Plan::Load 0.031 {
+package Attean::Plan::Load 0.032 {
 	use Moo;
 	use Encode;
 	use LWP::UserAgent;
