@@ -7,7 +7,7 @@ AtteanX::Parser::NTuples - Shared functionality for N-Triples and N-Quads parser
 
 =head1 VERSION
 
-This document describes AtteanX::Parser::NTuples version 0.029
+This document describes AtteanX::Parser::NTuples version 0.032
 
 =head1 SYNOPSIS
 
@@ -15,7 +15,7 @@ This document describes AtteanX::Parser::NTuples version 0.029
 
 =head1 DESCRIPTION
 
-...
+This module provides a base class for RDF formats N-Triples and N-Quads.
 
 =head1 METHODS
 
@@ -23,7 +23,7 @@ This document describes AtteanX::Parser::NTuples version 0.029
 
 =cut
 
-package AtteanX::Parser::NTuples 0.029 {
+package AtteanX::Parser::NTuples 0.032 {
 	use utf8;
 	use Moo;
 	use Attean;
@@ -199,6 +199,7 @@ the data read from the L<IO::Handle> object C<< $fh >>.
 				return Attean::Literal->new($value);
 			}
 		} else {
+			Carp::cluck;
 			die qq[Not valid N-Triples node start character '$char' at line $lineno, near "$_[0]"];
 		}
 	}
@@ -276,7 +277,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2014--2020 Gregory Todd Williams. This
+Copyright (c) 2014--2022 Gregory Todd Williams. This
 program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
