@@ -4,7 +4,6 @@ use v5.14;
 use warnings;
 use Test::Roo::Role;
 use Test::Moose;
-use Test::More;
 use Attean;
 use Attean::RDF;
 
@@ -20,6 +19,7 @@ test 'mutable etagcacheablequadstore' => sub {
     $store->remove_quad($q1);
     my $end		= $store->etag_value_for_quads();
     isnt($start, $end, "etag changed after update ($start => $end)");
+	$self->cleanup_store($store);
 };
 
 1;
